Functions in this package import filtered VCF files of SNP data and generate datasets to detect copy number variants, visualize them, and perform downstream analyses (e.g. environmental association analyses).
Main WGS functions
allele.info.WGS3Duplication/deletion detection using a negative-binomial depth model; no GC correction.
allele.info.WGS.GCcorSame framework with per-SNP GC-bias correction via SNP-centred windows.
Author
Piyal Karunarathne piyalkarumail@yahoo.com